==> vue-date-picker-2.8.0.tgz: package/lib/mobile.js <==
import { defineComponent, props, setup as _setup } from "@dft-vue-2-opentiny/vue-common";
import { renderless, api } from "@dft-vue-2-opentiny/vue-renderless/date-picker/vue";
import MiniPicker from "@dft-vue-2-opentiny/vue-mini-picker";
import Input from "@dft-vue-2-opentiny/vue-input";
import { iconCloseCircle } from "@dft-vue-2-opentiny/vue-icon";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinyMiniPicker: MiniPicker,
    TinyInput: Input,
    IconClose: iconCloseCircle()
  },
  props: [].concat(props, ["modelValue", "type", "clearable", "visible", "minDate", "maxDate", "formatter"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", [_c("tiny-input", {
    ref: "refrence",
    attrs: {
      "readOnly": "true",
      "_mode": _vm._mode
    },
    on: {
      "hook-mounted": _vm.hookMounted,
      "focus": _vm.showPickerAndLockScroll
    },
    model: {
      value: _vm.state.displayValue,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "displayValue", $$v);
      },
      expression: "state.displayValue"
    }
  }, [!_vm.state.clearable ? _c("icon-close", {
    attrs: {
      "slot": "suffix"
    },
    on: {
      "click": _vm.clearDisplayValue
    },
    slot: "suffix"
  }) : _vm._e()], 1), _c("tiny-mini-picker", {
    ref: "picker",
    attrs: {
      "columns": _vm.state.columns
    },
    on: {
      "change": _vm.onChange,
      "confirm": _vm.onConfirm,
      "cancel": _vm.onCancel
    },
    model: {
      value: _vm.state.visible,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "visible", $$v);
      },
      expression: "state.visible"
    }
  })], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobile as default
};

==> vue-date-picker-2.21.0.tgz: package/lib/mobile.js <==
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/date-picker/vue';
import MiniPicker from '@opentinyvue/vue-mini-picker';
import Input from '@opentinyvue/vue-input';
import { iconCloseCircle } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinyMiniPicker: MiniPicker,
    TinyInput: Input,
    IconClose: iconCloseCircle()
  },
  props: [].concat(props, ["modelValue", "type", "clearable", "visible", "minDate", "maxDate", "formatter"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", [_c("tiny-input", {
    ref: "refrence",
    attrs: {
      "readOnly": "true",
      "_mode": _vm._mode
    },
    on: {
      "hook-mounted": _vm.hookMounted,
      "focus": _vm.showPickerAndLockScroll
    },
    model: {
      value: _vm.state.displayValue,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "displayValue", $$v);
      },
      expression: "state.displayValue"
    }
  }, [!_vm.state.clearable ? _c("icon-close", {
    attrs: {
      "slot": "suffix"
    },
    on: {
      "click": _vm.clearDisplayValue
    },
    slot: "suffix"
  }) : _vm._e()], 1), _c("tiny-mini-picker", {
    ref: "picker",
    attrs: {
      "columns": _vm.state.columns
    },
    on: {
      "change": _vm.onChange,
      "confirm": _vm.onConfirm,
      "cancel": _vm.onCancel
    },
    model: {
      value: _vm.state.visible,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "visible", $$v);
      },
      expression: "state.visible"
    }
  })], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobile as default };
